Crate nubls

Structs

  • A PrivateKey represents a Scalar element within the order of the BLS12-381 curve. We have an Option<Scalar> field for a Fragment ID in the case of Threshold signatures.
  • A PublicKey represents an Affine element of the G_1 group on the BLS12-381 curve.
  • A Signature is an Affine element of the G_2 group on the BLS12-381 curve. We have an Option<Scalar> field for a Fragment ID in the case of Threshold signatures.

Enums

Traits

  • A trait that describes the Penumbral Proxy Re-Signature protocol. Given a Re-Signature key, a BLS signature can be re-signed from Bob’s key to Alice’s key.
  • A trait that describes a key that can be used for threshold cryptography protocols. The key that has this trait implemented on it can be split into n fragments where m fragments (the threshold) must be recovered to re-assemble the full key.
  • A trait that describes a signature from a threshold signing protocol. Given a threshold set of signature fragments, a full signature can be assembled and verified by its corresponding threshold key.