A trait that describes the Penumbral Proxy Re-Signature protocol.
Given a Re-Signature key, a BLS signature can be re-signed from Bob’s
key to Alice’s key.
A trait that describes a key that can be used for threshold cryptography
protocols. The key that has this trait implemented on it can be split into
n fragments where m fragments (the threshold) must be recovered to
re-assemble the full key.
A trait that describes a signature from a threshold signing protocol.
Given a threshold set of signature fragments, a full signature can be assembled
and verified by its corresponding threshold key.